pub struct HttpConnector { /* private fields */ }Expand description
A connector for the http scheme.
Performs DNS resolution in a thread pool, and then connects over TCP.
Implementations
Sourceimpl HttpConnector
impl HttpConnector
Sourcepub fn new(threads: usize) -> HttpConnector
pub fn new(threads: usize) -> HttpConnector
Construct a new HttpConnector.
Takes number of DNS worker threads.
Sourcepub fn new_with_handle(threads: usize, handle: Handle) -> HttpConnector
pub fn new_with_handle(threads: usize, handle: Handle) -> HttpConnector
Construct a new HttpConnector with a specific Tokio handle.
Sourcepub fn new_with_executor<E>(
executor: E,
handle: Option<Handle>,
) -> HttpConnector
pub fn new_with_executor<E>( executor: E, handle: Option<Handle>, ) -> HttpConnector
Construct a new HttpConnector.
Takes an executor to run blocking tasks on.
Sourcepub fn enforce_http(&mut self, is_enforced: bool)
pub fn enforce_http(&mut self, is_enforced: bool)
Option to enforce all Uris have the http scheme.
Enabled by default.
Sourcepub fn set_keepalive(&mut self, dur: Option<Duration>)
pub fn set_keepalive(&mut self, dur: Option<Duration>)
Set that all sockets have SO_KEEPALIVE set with the supplied duration.
If None, the option will not be set.
Default is None.
Sourcepub fn set_nodelay(&mut self, nodelay: bool)
pub fn set_nodelay(&mut self, nodelay: bool)
Set that all sockets have SO_NODELAY set to the supplied value nodelay.
Default is false.
Sourcepub fn set_local_address(&mut self, addr: Option<IpAddr>)
pub fn set_local_address(&mut self, addr: Option<IpAddr>)
Set that all sockets are bound to the configured address before connection.
If None, the sockets will not be bound.
Default is None.